# Change Log

## Version 0.1

### Version 0.1.3

* Fixed the installation to include the `pylatexenc` package.
* Fixed a bug where html files were being imported as text instead of as xml trees.

### Version 0.1.2

* Fixed a bug in LTI passport detection.

### Version 0.1.1

* Fixed some bugs.

### Version 0.1.0

This is the initial release.

* Detects a number of errors in XML structure, policy settings, block settings, and a few global errors.
